sttkeccentr: Estimates the Eccentricity of a Statokinesigram.
Description
Computes the eccentricity of the confidence ellipse of a given statokinesigram.
Usage
sttkeccentr(dados)
Value
The eccentricity of the given statokinesigram eccentr.
Arguments
dados
data frame with two columns "x" and "y"
Author
Jose Magalhaes de Oliveira
Details
'dados' is a data frame containing two columns named "x" and "y". The pairs (x, y) are the coordinates of the center of pressure acquired in a period of time.