Learn R Programming

stabilo (version 0.1.1)

sttknorm: Standardizes Statokinesigrams

Description

confines a given statokinesigram in a circumference of radius equal to 1, without spatially distorting its shape. The circumference contains 95 percent of statokinesigram's points.

Usage

sttknorm(dados)

Value

The normalized statokinesigram stknorm.

Arguments

dados

data frame with two columns "x" and "y"

Author

Jose Magalhaes de Oliveira

Details

'dados' is a data frame containing two columns named "x" and "y". The pairs (x, y) are the coordinates of the center of pressure acquired in a period of time.

See Also

sttkarea, sttklength

Examples

Run this code
x <- c(1,3,7,5,9,4,3,6,8,2,8,9,4,5,7,3,4,7,9,3,2,5,3,4,8,2,9,7,4,2)
y <- c(6,3,9,1,3,7,4,9,6,1,7,3,9,7,2,6,3,4,8,1,9,3,6,8,1,6,2,9,8,3)

COP <- data.frame(x, y)

COPnorm <- sttknorm(COP)


Run the code above in your browser using DataLab