sttksdx: Quantifies the Lateral Sway Amplitude of a Statokinesigram
Description
Computes the standard deviation of lateral displacement of the center of pressure.
Usage
sttksdx(dados)
Value
The standard deviation of x sdx.
Arguments
dados
data frame with two columns "x" and "y"
Author
Jose Magalhaes de Oliveira
Details
'dados' is a data frame containing two columns named "x" and "y". The pairs (x, y) are the coordinates of the center of pressure acquired in a period of time.