sttkymdfreq: Quantifies the Median Frequency of the Anteroposterior Displacement of COP.
Description
Computes the median frequency of the anteroposterior displacement of the center of pressure.
Usage
sttkymdfreq(dados, sampfreq)
Value
The median frequency of the y displacement for the given statokinesigram FMy.
Arguments
dados
data frame with two columns "x" and "y"
sampfreq
number The sampling frequency
Author
Jose Magalhaes de Oliveira
Details
'dados' is a data frame containing two columns named "x" and "y". The pairs (x, y) are the coordinates of the center of pressure acquired in a period of time.