confines a given statokinesigram in a circumference of radius equal to 1, without spatially distorting its shape. The circumference contains 95 percent of statokinesigram's points.
Usage
sttknorm(dados)
Value
The normalized statokinesigram stknorm.
Arguments
dados
data frame with two columns "x" and "y"
Author
Jose Magalhaes de Oliveira
Details
'dados' is a data frame containing two columns named "x" and "y". The pairs (x, y) are the coordinates of the center of pressure acquired in a period of time.