sttksdy: Quantifies the front-and-back Sway Amplitude of a Statokinesigram
Description
Computes the standard deviation of front-and-back displacement of the center of pressure.
Usage
sttksdy(dados)
Value
The standard deviation of y sdy.
Arguments
dados
data frame with two columns "x" and "y"
Author
Jose Oliveira
Details
'dados' is a data frame containing two columns named "x" and "y". The pairs (x, y) are the coordinates of the center of pressure acquired in a period of time.